@@ -13,7 +13,7 @@ def run_ml_cli_pipeline(args, config_path, ml_cli_template_path):
     build_tags_string = args.build_tags
     config_aml_path = args.config_aml_path
     skip_train_execution = args.skip_train_execution
-    mlcli_template_json = args.datasets_configuration_json
+    mlcli_template_json = args.mlcli_template_json
     datasets_configuration_json = args.datasets_configuration_json
 
     build_tags = {}
